// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_WIN32_BASE_BROWSER_INFO_H_
#define MOZC_WIN32_BASE_BROWSER_INFO_H_

#include <windows.h>

#include "base/port.h"

namespace mozc {
namespace win32 {

class FocusHierarchyObserver;

class BrowserInfo {
 public:
  enum BrowserType {
    kBrowserTypeUnknown = 0,
    kBrowserTypeChrome,
    kBrowserTypeFirefox,
    kBrowserTypeIE,
    kBrowserTypeOpera,
  };
  struct Version {
    Version();
    int major;
    int minor;
    int build;
    int revision;
  };

  static BrowserType GetBrowerType();
  static Version GetProcessModuleVersion();

  static bool IsInIncognitoMode(
      const FocusHierarchyObserver &focus_hierarchy_observer);
  static bool IsOnChromeOmnibox(
      const FocusHierarchyObserver &focus_hierarchy_observer);

  static void OnDllProcessAttach(HINSTANCE module_handle, bool static_loading);
  static void OnDllProcessDetach(HINSTANCE module_handle,
                                 bool process_shutdown);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(BrowserInfo);
};

}  // namespace win32
}  // namespace mozc

#endif  // MOZC_WIN32_BASE_BROWSER_INFO_H_
